/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/
 */
package org.phenotips.components;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.manager.ComponentManager;
import org.xwiki.observation.EventListener;
import org.xwiki.observation.event.ApplicationStartedEvent;
import org.xwiki.observation.event.Event;

import java.util.Arrays;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Provider;
import javax.inject.Singleton;

/**
 * Provides access to the component manager to non-components. The component manager type returned is "context", which
 * takes into account custom components available in the current scope: local wiki components, user-specific components,
 * etc.
 *
 * @version $Id: 16ed7f60359faffcb2c9ff734f134bcbf5e7c534 $
 * @since 1.0M8
 */
@Component
@Named("cmregistry")
@Singleton
public class ComponentManagerRegistry implements EventListener
{
    /** The actual component manager provider that we're using. */
    @Inject
    @Named("context")
    private static Provider<ComponentManager> cmProvider;

    /**
     * Use this method to get the current context component manager.
     *
     * @return the component manager active in the current context, or the root component manager if the context doesn't
     *         have a custom component manager registered
     */
    public static ComponentManager getContextComponentManager()
    {
        return cmProvider.get();
    }

    @Override
    public String getName()
    {
        return "cmregistry";
    }

    @Override
    public List<Event> getEvents()
    {
        return Arrays.<Event>asList(new ApplicationStartedEvent());
    }

    @Override
    public void onEvent(Event event, Object source, Object data)
    {
        // Nothing to do, we just wanted to get the component manager provider injected
    }
}
